@@ -6,18 +6,18 @@ SPDX-License-Identifier: MIT
 
 # Colors
 
-FMT_RED = '\033[31m'
-FMT_ORANGE = '\033[33m'
-FMT_GRAY = '\033[37m'
-FMT_CYAN = '\033[36m'
-FMT_GREEN = '\033[32m'
-FMT_MAGENTA = '\033[35m'
-FMT_BLUE = '\033[34m'
-FMT_YELLOW = '\033[93m'
+FMT_RED = "\033[31m"
+FMT_ORANGE = "\033[33m"
+FMT_GRAY = "\033[37m"
+FMT_CYAN = "\033[36m"
+FMT_GREEN = "\033[32m"
+FMT_MAGENTA = "\033[35m"
+FMT_BLUE = "\033[34m"
+FMT_YELLOW = "\033[93m"
 
-FMT_BOLD = '\033[1m'
-FMT_NONE = '\033[0m'
-FMT_UNDERLINE = '\033[4m'
+FMT_BOLD = "\033[1m"
+FMT_NONE = "\033[0m"
+FMT_UNDERLINE = "\033[4m"
 
 FMT_ERROR = FMT_RED + FMT_BOLD
 
@@ -26,4 +26,4 @@ FMT_PARSE = FMT_CYAN + FMT_BOLD
 FMT_CPU = FMT_BLUE + FMT_BOLD
 FMT_SYSCALL = FMT_YELLOW + FMT_BOLD
 FMT_DEBUG = FMT_MAGENTA + FMT_BOLD
-FMT_CSR = FMT_ORANGE + FMT_BOLD
\ No newline at end of file
+FMT_CSR = FMT_ORANGE + FMT_BOLD
