@@ -5,7 +5,6 @@ SPDX-License-Identifier: MIT
 """
 
 from .instruction_set import *
-from riscemu.core.exceptions import INS_NOT_IMPLEMENTED
 
 
 class RV32M(InstructionSet):
@@ -19,13 +18,15 @@ class RV32M(InstructionSet):
 
     def instruction_mulh(self, ins: "Instruction"):
         rd, rs1, rs2 = self.parse_rd_rs_rs(ins)
-        self.regs.set(rd, (rs1 * rs2) >> 32)
+        self.regs.set(rd, Int32((rs1.signed().value * rs2.signed().value) >> 32))
 
     def instruction_mulhsu(self, ins: "Instruction"):
-        INS_NOT_IMPLEMENTED(ins)
+        rd, rs1, rs2 = self.parse_rd_rs_rs(ins)
+        self.regs.set(rd, Int32((rs1.signed().value * rs2.unsigned_value) >> 32))
 
     def instruction_mulhu(self, ins: "Instruction"):
-        INS_NOT_IMPLEMENTED(ins)
+        rd, rs1, rs2 = self.parse_rd_rs_rs(ins)
+        self.regs.set(rd, UInt32((rs1.unsigned_value * rs2.unsigned_value) >> 32))
 
     def instruction_div(self, ins: "Instruction"):
         rd, rs1, rs2 = self.parse_rd_rs_rs(ins)
