@@ -19,6 +19,74 @@ from .core import (
     ParseException,
 )
 
+REG_NAME_CANONICALIZER = {
+    "fp": "s0",
+    "x0": "zero",
+    "x1": "ra",
+    "x2": "sp",
+    "x3": "gp",
+    "x4": "tp",
+    "x5": "t0",
+    "x6": "t1",
+    "x7": "t2",
+    "x8": "s0",
+    "x9": "s1",
+    "x10": "a0",
+    "x11": "a1",
+    "x12": "a2",
+    "x13": "a3",
+    "x14": "a4",
+    "x15": "a5",
+    "x16": "a6",
+    "x17": "a7",
+    "x18": "s2",
+    "x19": "s3",
+    "x20": "s4",
+    "x21": "s5",
+    "x22": "s6",
+    "x23": "s7",
+    "x24": "s8",
+    "x25": "s9",
+    "x26": "s10",
+    "x27": "s11",
+    "x28": "t3",
+    "x29": "t4",
+    "x30": "t5",
+    "x31": "t6",
+    "f0": "ft0",
+    "f1": "ft1",
+    "f2": "ft2",
+    "f3": "ft3",
+    "f4": "ft4",
+    "f5": "ft5",
+    "f6": "ft6",
+    "f7": "ft7",
+    "f8": "fs0",
+    "f9": "fs1",
+    "f10": "fa0",
+    "f11": "fa1",
+    "f12": "fa2",
+    "f13": "fa3",
+    "f14": "fa4",
+    "f15": "fa5",
+    "f16": "fa6",
+    "f17": "fa7",
+    "f18": "fs2",
+    "f19": "fs3",
+    "f20": "fs4",
+    "f21": "fs5",
+    "f22": "fs6",
+    "f23": "fs7",
+    "f24": "fs8",
+    "f25": "fs9",
+    "f26": "fs10",
+    "f27": "fs11",
+    "f28": "ft8",
+    "f29": "ft9",
+    "f30": "ft10",
+    "f31": "ft11",
+}
+
 
 def parse_instruction(token: Token, args: Tuple[str], context: ParseContext):
     if context.section is None:
@@ -28,7 +96,10 @@ def parse_instruction(token: Token, args: Tuple[str], context: ParseContext):
             "{} {} encountered in invalid context: {}".format(token, args, context)
         )
     ins = SimpleInstruction(
-        token.value, args, context.context, context.current_address()
+        token.value,
+        parse_instruction_arguments(args),
+        context.context,
+        context.current_address(),
     )
     context.section.data.append(ins)
 
@@ -112,6 +183,30 @@ def take_arguments(tokens: Peekable[Token]) -> Iterable[str]:
         # raise ParseException("Expected newline, instead got {}".format(tokens.peek()))
 
 
+def parse_instruction_arguments(args: Tuple[str]) -> Tuple[str]:
+    """
+    Parses argument Tuples of instructions. In this process canonicalize register names
+    :param args: A tuple of an instructions arguments
+    :return: A tuple of an instructions parsed arguments
+    """
+    return tuple(canonicalize_register_names(args))
+
+
+def canonicalize_register_names(args: Tuple[str]) -> Iterable[str]:
+    """
+    Translate register indices names to ABI names. Leaves other arguments unchanged.
+    Examples:
+    "x0" -> "zero"
+    "x5" -> "t0"
+    "x8" -> "s0"
+    "fp" -> "s0"
+    :param args: A tuple of an instructions arguments
+    :return: An iterator over the arguments of an instruction, but with canonicalized register names
+    """
+    for arg in args:
+        yield REG_NAME_CANONICALIZER.get(arg, arg)
+
+
 class AssemblyFileLoader(ProgramLoader):
     """
     This class loads assembly files written by hand. It understands some assembler
